@@ -1,7 +1,8 @@
+from typing import List
+
 from boto3 import client
 
 from aws_managers.s3.s3_container_mixin import S3ContainerMixin
-# get_execution_role()
 from aws_managers.s3.s3_folder_manager import S3FolderManager
 from aws_managers.s3.utils import s3_bucket_uri
 
@@ -34,7 +35,15 @@ class S3BucketManager(
         """
         return self._bucket_uri
 
+    def folders(self, deep: bool = False) -> List[S3FolderManager]:
+        """
+        Return an S3FolderManager reference to each sub-folder in the folder.
+        """
+        return [
+            S3FolderManager(self._bucket_name, folder_key)
+            for folder_key in self.folder_keys(deep=deep)
+        ]
+
     def __truediv__(self, folder: str):
 
         return S3FolderManager(self.name, folder)
-
